@@ -21,19 +21,19 @@ use std::time::Duration;
 
 use chrono::{DateTime, FixedOffset};
 use fallible_iterator::{FallibleIterator, IntoFallibleIterator};
+use osproto::common::IdAndName;
 use waiter::{Waiter, WaiterCurrentState};
 
 use super::super::common::{
-    self, DeletionWaiter, FlavorRef, ImageRef, IntoVerified, KeyPairRef, NetworkRef, PortRef,
-    ProjectRef, Refresh, ResourceIterator, ResourceQuery, UserRef, VolumeRef,
+    DeletionWaiter, FlavorRef, ImageRef, IntoVerified, KeyPairRef, NetworkRef, PortRef, ProjectRef,
+    Refresh, ResourceIterator, ResourceQuery, UserRef, VolumeRef,
 };
 #[cfg(feature = "image")]
 use super::super::image::Image;
 use super::super::session::Session;
 use super::super::utils::Query;
 use super::super::{Error, ErrorKind, Result, Sort};
-use super::base::V2API;
-use super::{protocol, BlockDevice, KeyPair};
+use super::{api, protocol, BlockDevice, KeyPair};
 
 /// A query to server list.
 #[derive(Clone, Debug)]
@@ -63,7 +63,7 @@ pub struct Server {
 #[derive(Clone, Debug)]
 pub struct ServerSummary {
     session: Rc<Session>,
-    inner: common::protocol::IdAndName,
+    inner: IdAndName,
 }
 
 /// Waiter for server status to change.
@@ -106,7 +106,7 @@ pub struct ServerCreationWaiter {
 impl Refresh for Server {
     /// Refresh the server.
     fn refresh(&mut self) -> Result<()> {
-        self.inner = self.session.get_server_by_id(&self.inner.id)?;
+        self.inner = api::get_server_by_id(&self.session, &self.inner.id)?;
         Ok(())
     }
 }
@@ -114,7 +114,7 @@ impl Refresh for Server {
 impl Server {
     /// Create a new Server object.
     pub(crate) fn new(session: Rc<Session>, inner: protocol::Server) -> Result<Server> {
-        let flavor = session.get_flavor(&inner.flavor.id)?;
+        let flavor = api::get_flavor(&session, &inner.flavor.id)?;
         Ok(Server {
             session,
             inner,
@@ -132,7 +132,7 @@ impl Server {
 
     /// Load a Server object.
     pub(crate) fn load<Id: AsRef<str>>(session: Rc<Session>, id: Id) -> Result<Server> {
-        let inner = session.get_server(id)?;
+        let inner = api::get_server(&session, id)?;
         Server::new(session, inner)
     }
 
@@ -270,7 +270,7 @@ impl Server {
 
     /// Delete the server.
     pub fn delete(self) -> Result<DeletionWaiter<Server>> {
-        self.session.delete_server(&self.inner.id)?;
+        api::delete_server(&self.session, &self.inner.id)?;
         Ok(DeletionWaiter::new(
             self,
             Duration::new(120, 0),
@@ -285,8 +285,7 @@ impl Server {
     ) -> Result<ServerStatusWaiter<'server>> {
         let mut args = HashMap::new();
         let _ = args.insert("type", reboot_type);
-        self.session
-            .server_action_with_args(&self.inner.id, "reboot", args)?;
+        api::server_action_with_args(&self.session, &self.inner.id, "reboot", args)?;
         Ok(ServerStatusWaiter {
             server: self,
             target: protocol::ServerStatus::Active,
@@ -295,8 +294,7 @@ impl Server {
 
     /// Start the server, optionally wait for it to be active.
     pub fn start<'server>(&'server mut self) -> Result<ServerStatusWaiter<'server>> {
-        self.session
-            .server_simple_action(&self.inner.id, "os-start")?;
+        api::server_simple_action(&self.session, &self.inner.id, "os-start")?;
         Ok(ServerStatusWaiter {
             server: self,
             target: protocol::ServerStatus::Active,
@@ -305,8 +303,7 @@ impl Server {
 
     /// Stop the server, optionally wait for it to be powered off.
     pub fn stop<'server>(&'server mut self) -> Result<ServerStatusWaiter<'server>> {
-        self.session
-            .server_simple_action(&self.inner.id, "os-stop")?;
+        api::server_simple_action(&self.session, &self.inner.id, "os-stop")?;
         Ok(ServerStatusWaiter {
             server: self,
             target: protocol::ServerStatus::ShutOff,
@@ -387,7 +384,7 @@ impl ServerSummary {
     /// Delete the server.
     pub fn delete(self) -> Result<()> {
         // TODO(dtantsur): implement wait
-        self.session.delete_server(&self.inner.id)
+        api::delete_server(&self.session, &self.inner.id)
     }
 }
 
@@ -507,20 +504,6 @@ impl ServerQuery {
         ResourceIterator::new(self)
     }
 
-    /// Convert this query into an iterator executing the request.
-    ///
-    /// This iterator yields full `Server` objects. If you only need IDs
-    /// and/or names, use `into_iter` to save bandwidth.
-    ///
-    /// Returns a `FallibleIterator`, which is an iterator with each `next`
-    /// call returning a `Result`.
-    ///
-    /// Note that no requests are done until you start iterating.
-    #[deprecated(since = "0.2.0", note = "Use .detailed().into_iter()")]
-    pub fn into_iter_detailed(self) -> ResourceIterator<DetailedServerQuery> {
-        self.detailed().into_iter()
-    }
-
     /// Execute this request and return all results.
     ///
     /// A convenience shortcut for `self.into_iter().collect()`.
@@ -560,9 +543,7 @@ impl ResourceQuery for ServerQuery {
 
     fn fetch_chunk(&self, limit: Option<usize>, marker: Option<String>) -> Result<Vec<Self::Item>> {
         let query = self.query.with_marker_and_limit(limit, marker);
-        Ok(self
-            .session
-            .list_servers(&query)?
+        Ok(api::list_servers(&self.session, &query)?
             .into_iter()
             .map(|srv| ServerSummary {
                 session: self.session.clone(),
@@ -602,7 +583,7 @@ impl ResourceQuery for DetailedServerQuery {
 
     fn fetch_chunk(&self, limit: Option<usize>, marker: Option<String>) -> Result<Vec<Self::Item>> {
         let query = self.inner.query.with_marker_and_limit(limit, marker);
-        let servers = self.inner.session.list_servers_detail(&query)?;
+        let servers = api::list_servers_detail(&self.inner.session, &query)?;
         let mut result = Vec::with_capacity(servers.len());
         for srv in servers {
             result.push(Server::new(self.inner.session.clone(), srv)?);
@@ -675,7 +656,7 @@ impl NewServer {
             networks: convert_networks(&self.session, self.nics)?,
         };
 
-        let server_ref = self.session.create_server(request)?;
+        let server_ref = api::create_server(&self.session, request)?;
         Ok(ServerCreationWaiter {
             server: Server::load(self.session, server_ref.id)?,
         })
@@ -696,12 +677,6 @@ impl NewServer {
         self.nics.push(ServerNIC::FromNetwork(network.into()));
     }
 
-    /// Add a virtual NIC to the new server.
-    #[deprecated(since = "0.2.3", note = "Use nics().push")]
-    pub fn add_nic(&mut self, nic: ServerNIC) {
-        self.nics.push(nic);
-    }
-
     /// Add a virtual NIC with this port to the new server.
     #[inline]
     pub fn add_port<P>(&mut self, port: P)
@@ -884,9 +859,9 @@ impl IntoFallibleIterator for ServerQuery {
 
     type Error = Error;
 
-    type IntoIter = ResourceIterator<ServerQuery>;
+    type IntoFallibleIter = ResourceIterator<ServerQuery>;
 
-    fn into_fallible_iterator(self) -> Self::IntoIter {
+    fn into_fallible_iter(self) -> Self::IntoFallibleIter {
         self.into_iter()
     }
 }
@@ -896,9 +871,9 @@ impl IntoFallibleIterator for DetailedServerQuery {
 
     type Error = Error;
 
-    type IntoIter = ResourceIterator<DetailedServerQuery>;
+    type IntoFallibleIter = ResourceIterator<DetailedServerQuery>;
 
-    fn into_fallible_iterator(self) -> Self::IntoIter {
+    fn into_fallible_iter(self) -> Self::IntoFallibleIter {
         self.into_iter()
     }
 }
